=======
Hacking
=======

Fork me on: https://bitbucket.org/icemac/icemac.addressbook

See `Source installation`_, too.

.. _`Source installation` : https://bitbucket.org/icemac/icemac.addressbook/wiki/Source%20installation
